import { defineStore } from 'pinia';
import { userLoginPost, userLogoutPost } from '../../api/Users';
import { userRegisterPost, userForgetPost, userPasswordPut } from '../../api/Users';

export const useAuthStore = defineStore('auth', {
  state: () => ({
    user: null,
    isAuthenticated: false,
    isAdmin: false,
  }),
  actions: {
    async login(username, password) {
      try {
        const response = await userLoginPost({ username, password });
        this.user = response.data;
        this.isAuthenticated = true;
        this.isAdmin = this.user.role === 'admin';
        return true;
      } catch (error) {
        this.handleError('登录失败', error);
        return false;
      }
    },
    async logout() {
      try {
        await userLogoutPost();
        this.resetAuthState();
      } catch (error) {
        this.handleError('登出失败', error);
      }
    },
    async register(userData) {
      try {
        await userRegisterPost(userData);
        return true;
      } catch (error) {
        this.handleError('注册失败', error);
        return false;
      }
    },
    async forgotPassword(userData) {
      try {
        await userForgetPost(userData);
        return true;
      } catch (error) {
        this.handleError('密码重置请求失败', error);
        return false;
      }
    },
    async changePassword(oldPassword, newPassword) {
      try {
        await userPasswordPut({ oldPassword, newPassword });
        return true;
      } catch (error) {
        this.handleError('密码更改失败', error);
        return false;
      }
    },
    resetAuthState() {
      this.user = null;
      this.isAuthenticated = false;
      this.isAdmin = false;
    },
    handleError(message, error) {
      console.error(message, error);
    },
  },
});